SecretExt

Trait SecretExt 

pub(crate) trait SecretExt {
    // Required methods
    async fn restore_sessions() -> Result<Vec<StoredSession>, SecretError>;
    async fn store_session(session: StoredSession) -> Result<(), SecretError>;
    async fn delete_session(session: &StoredSession);
}
Trait implemented by secret backends.

Required Methods

async fn restore_sessions() -> Result<Vec<StoredSession>, SecretError>

Retrieves all sessions stored in the secret backend.

async fn store_session(session: StoredSession) -> Result<(), SecretError>

Store the given session into the secret backend, overwriting any previously stored session with the same attributes.

async fn delete_session(session: &StoredSession)

Delete the given session from the secret backend.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors